@@ -24,3 +24,16 @@ requires "_build_backend";
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Cmd::WithDSN - Role for commands with a C<--dsn> argument.
+
+=head1 DESCRIPTION
+
+This is an abstract role. For concrete implementations see
+L<KiokuDB::Cmd::WithDSN::Create>, L<KiokuDB::Cmd::WithDSN::Read> and
+L<KiokuDB::Cmd::WithDSN::Write>.
+
